@TOP@

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* These defines are needed below.  */
#undef __TYPE8__
#undef __TYPE16__
#undef __TYPE32__

/* Define if you want to use lookup tables (faster, but uses memory) */
#undef USE_LOOKUPTABLE

/* Define if you want to use the audiofile library */
#undef USE_AUDIOFILE

/* Define if you want to use the mad mpeg audio decoder library */
#undef USE_MAD

@BOTTOM@

#if !HAVE_INT8_T
typedef signed __TYPE8__ int8_t;
#endif
#if !HAVE_INT16_T
typedef signed __TYPE16__ int16_t;
#endif
#if !HAVE_INT32_T
typedef signed __TYPE32__ int32_t;
#endif
#if !HAVE_UINT8_T
typedef unsigned __TYPE8__ uint8_t;
#endif
#if !HAVE_UINT16_T
typedef unsigned __TYPE16__ uint16_t;
#endif
#if !HAVE_UINT32_T
typedef unsigned __TYPE32__ uint32_t;
#endif

/* end of file acconfig.h */
